var examples =
[
    [ "Shape_regularization/regularize_simple.cpp", "Shape_regularization_2regularize_simple_8cpp-example.html", null ],
    [ "Shape_regularization/regularize_15_segments.cpp", "Shape_regularization_2regularize_15_segments_8cpp-example.html", null ],
    [ "Shape_regularization/regularize_100_segments_angles.cpp", "Shape_regularization_2regularize_100_segments_angles_8cpp-example.html", null ],
    [ "Shape_regularization/regularize_100_segments_offsets.cpp", "Shape_regularization_2regularize_100_segments_offsets_8cpp-example.html", null ],
    [ "Shape_regularization/regularize_real_data_2.cpp", "Shape_regularization_2regularize_real_data_2_8cpp-example.html", null ],
    [ "Shape_regularization/regularize_framework.cpp", "Shape_regularization_2regularize_framework_8cpp-example.html", null ],
    [ "Shape_regularization/regularize_contour.cpp", "Shape_regularization_2regularize_contour_8cpp-example.html", null ],
    [ "Shape_regularization/regularize_closed_contour.cpp", "Shape_regularization_2regularize_closed_contour_8cpp-example.html", null ],
    [ "Shape_regularization/regularize_open_contour.cpp", "Shape_regularization_2regularize_open_contour_8cpp-example.html", null ],
    [ "Shape_regularization/regularize_planes.cpp", "Shape_regularization_2regularize_planes_8cpp-example.html", null ]
];